@@ -9,7 +9,7 @@ from musicscore.musicxml.types.complextypes.harmonic import Artificial, BasePitc
 from musicscore.musicxml.types.complextypes.notations import Technical
 from musicscore.musicxml.types.complextypes.technical import Harmonic
 
-path = os.path.abspath(__file__).split('.')[0]
+path = str(os.path.abspath(__file__).split('.')[0])
 
 
 class Test(TestCase):
@@ -17,7 +17,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[4], midis=[(60, 65)])
+        sf = SimpleFormat(quarter_durations=[4], midis=[(60, 65)])
         chord = sf.chords[0]
         notations = chord.add_child(Notations())
         technical = notations.add_child(Technical())
@@ -31,7 +31,7 @@ class Test(TestCase):
         # self.score.write(xml_path)
 
     def test_2(self):
-        sf = SimpleFormat(durations=[1.5, 2, 3, 2.33, 3.66], midis=5*[60])
+        sf = SimpleFormat(quarter_durations=[1.5, 2, 3, 2.33, 3.66], midis=5 * [60])
         for chord in sf.chords:
             chord.add_harmonic(5)
         sf.to_stream_voice().add_to_score(self.score)
