@@ -1,12 +1,11 @@
-from unittest import TestCase
 import os
+from unittest import TestCase
 
 from musicscore.musicstream.streamvoice import SimpleFormat
-from musicscore.musictree.midi import C, D, E, F, G, A, B
+from musicscore.musictree.midi import C, D, E, F, B
 from musicscore.musictree.treescoretimewise import TreeScoreTimewise
-from tests.score_templates.xml_test_score import TestScore
 
-path = os.path.abspath(__file__).split('.')[0]
+path = str(os.path.abspath(__file__).split('.')[0])
 
 
 class Test(TestCase):
@@ -29,7 +28,7 @@ class Test(TestCase):
 
         durations = [2, 3, 1, 2, 3, 1, 4, 2, 4, 2, 2, 3, 1, 2, 2, 2, 2, 3, 1, 1, 4]
         durations = [d / 2 for d in durations]
-        sf = SimpleFormat(midis=midis, durations=durations)
+        sf = SimpleFormat(midis=midis, quarter_durations=durations)
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 1)
 
