@@ -14,7 +14,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[1, 1, 1, 1], midis=[60, (61, 62, 63), (64, 65), (67)])
+        sf = SimpleFormat(quarter_durations=[1, 1, 1, 1], midis=[60, (61, 62, 63), (64, 65), (67)])
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 1)
         voice = self.score.get_measure(1).get_part(1).get_voice(1)
